==> jc-1.4.0.tar.gz: soot/jimple/parser/lexer/LexerException.h <==
// public class soot.jimple.parser.lexer.LexerException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class d4ec105ca792f934 soot_jimple_parser_lexer_LexerException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_soot_jimple_parser_lexer_LexerException_H_
#define _JC_soot_jimple_parser_lexer_LexerException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_lexer_LexerException$sub_refs	_jc_soot_jimple_parser_lexer_LexerException$sub_refs;
typedef struct _jc_soot_jimple_parser_lexer_LexerException$sub_nonrefs	_jc_soot_jimple_parser_lexer_LexerException$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_lexer_LexerException$refs	_jc_soot_jimple_parser_lexer_LexerException$refs;
typedef struct _jc_soot_jimple_parser_lexer_LexerException$nonrefs	_jc_soot_jimple_parser_lexer_LexerException$nonrefs;
typedef struct _jc_soot_jimple_parser_lexer_LexerException$object	_jc_soot_jimple_parser_lexer_LexerException$object;

typedef const struct _jc_soot_jimple_parser_lexer_LexerException$vmethods	_jc_soot_jimple_parser_lexer_LexerException$vmethods;
typedef const struct _jc_soot_jimple_parser_lexer_LexerException$vtable	_jc_soot_jimple_parser_lexer_LexerException$vtable;
typedef const struct _jc_soot_jimple_parser_lexer_LexerException$vtype	_jc_soot_jimple_parser_lexer_LexerException$vtype;

// Constructors
extern void _jc_soot_jimple_parser_lexer_LexerException$method$_init$c31b894660454d13(_jc_env *, struct _jc_soot_jimple_parser_lexer_LexerException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_soot_jimple_parser_lexer_LexerException$vmethods {
};

// Vtable
struct _jc_soot_jimple_parser_lexer_LexerException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_soot_jimple_parser_lexer_LexerException$vmethods	soot_jimple_parser_lexer_LexerException;
};

// Vtype
struct _jc_soot_jimple_parser_lexer_LexerException$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_lexer_LexerException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_lexer_LexerException$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_lexer_LexerException$refs {
    _jc_soot_jimple_parser_lexer_LexerException$sub_refs	soot_jimple_parser_lexer_LexerException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_lexer_LexerException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_lexer_LexerException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_soot_jimple_parser_lexer_LexerException$sub_nonrefs	soot_jimple_parser_lexer_LexerException;
};

// Object instance structure
struct _jc_soot_jimple_parser_lexer_LexerException$object {
	_jc_soot_jimple_parser_lexer_LexerException$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_lexer_LexerException$vtype	*vtype;
	_jc_soot_jimple_parser_lexer_LexerException$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_lexer_LexerException$vtype _jc_soot_jimple_parser_lexer_LexerException$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_lexer_LexerException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_lexer_LexerException$class_object;

#endif	/* _JC_soot_jimple_parser_lexer_LexerException_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/lexer/LexerException.h <==
// public class soot.jimple.parser.lexer.LexerException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class d4ec105ca792f934 soot_jimple_parser_lexer_LexerException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_soot_jimple_parser_lexer_LexerException_H_
#define _JC_soot_jimple_parser_lexer_LexerException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_lexer_LexerException$sub_refs	_jc_soot_jimple_parser_lexer_LexerException$sub_refs;
typedef struct _jc_soot_jimple_parser_lexer_LexerException$sub_nonrefs	_jc_soot_jimple_parser_lexer_LexerException$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_lexer_LexerException$refs	_jc_soot_jimple_parser_lexer_LexerException$refs;
typedef struct _jc_soot_jimple_parser_lexer_LexerException$nonrefs	_jc_soot_jimple_parser_lexer_LexerException$nonrefs;
typedef struct _jc_soot_jimple_parser_lexer_LexerException$object	_jc_soot_jimple_parser_lexer_LexerException$object;

typedef const struct _jc_soot_jimple_parser_lexer_LexerException$vmethods	_jc_soot_jimple_parser_lexer_LexerException$vmethods;
typedef const struct _jc_soot_jimple_parser_lexer_LexerException$vtable	_jc_soot_jimple_parser_lexer_LexerException$vtable;
typedef const struct _jc_soot_jimple_parser_lexer_LexerException$vtype	_jc_soot_jimple_parser_lexer_LexerException$vtype;

// Constructors
extern void _jc_soot_jimple_parser_lexer_LexerException$method$_init$c31b894660454d13(_jc_env *, struct _jc_soot_jimple_parser_lexer_LexerException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_parser_lexer_LexerException$vmethods {
};

// Vtable
struct _jc_soot_jimple_parser_lexer_LexerException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_soot_jimple_parser_lexer_LexerException$vmethods	soot_jimple_parser_lexer_LexerException;
};

// Vtype
struct _jc_soot_jimple_parser_lexer_LexerException$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_lexer_LexerException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_lexer_LexerException$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_lexer_LexerException$refs {
    _jc_soot_jimple_parser_lexer_LexerException$sub_refs	soot_jimple_parser_lexer_LexerException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_lexer_LexerException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_lexer_LexerException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_soot_jimple_parser_lexer_LexerException$sub_nonrefs	soot_jimple_parser_lexer_LexerException;
};

// Object instance structure
struct _jc_soot_jimple_parser_lexer_LexerException$object {
	_jc_soot_jimple_parser_lexer_LexerException$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_lexer_LexerException$vtype	*vtype;
	_jc_soot_jimple_parser_lexer_LexerException$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_lexer_LexerException$vtype _jc_soot_jimple_parser_lexer_LexerException$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_lexer_LexerException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_lexer_LexerException$class_object;

#endif	/* _JC_soot_jimple_parser_lexer_LexerException_H_ */
